@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -22,9 +22,7 @@ GravatarCacheTest::GravatarCacheTest(QObject *parent)
 {
 }
 
-GravatarCacheTest::~GravatarCacheTest()
-{
-}
+GravatarCacheTest::~GravatarCacheTest() = default;
 
 void GravatarCacheTest::initTestCase()
 {
